using FamilyTreeAPI.Entities;

namespace FamilyTreeAPI.Interface;

public interface ILookup
{
    Task<ResultModel<int>> SaveLookupAsync(LookupEditDto lookup);
    Task<ResultModel<List<LookupDto>>> GetLookupAsync(string type);
    Task<ResultModel<Dictionary<string, LookupDto>>> GetLookupDicAsync(string type);
    Task<ResultModel<List<LookupEditDto>>> GetLookupEditAsync(string type);
    Task<ResultModel<LookupEditDto>> GetLookupEditByIdAsync(int codeId, string type);
    Task<ResultModel<List<LookupDto>>> GetPersonsAsync();
    Task<ResultModel<List<LookupDto>>> GetStaffAsync();
  

}
